# New Prod Config

## 20230428

## Short description of the config

Config for a galactic source with dec 22.47 and NSB tuning.
Started from prod `20230315_src_dec2276_tuned_nsb` with new lstchain config.


## Why this config is needed

The feature `az_tel` must be used to analyse real data.
